@@ -116,6 +116,34 @@ class Pandora:
 
 		return parsed
 
+	def addSeed( self, stationId=None, musicId=None):
+		if stationId == None:
+			stationId = self.curStation
+		if musicId == None:
+			return
+
+		reqUrl = BASE_URL_LID %( self.rid, self.lid, "addSeed" )
+
+		args = ( _inttime(), self.authToken, stationId, musicId )
+
+		req = xmlrpclib.dumps( args, "station.addSeed" )
+
+		req = req.replace( "\n", "" )
+		enc = crypt.encryptString( req )
+	
+		u = urlopen( reqUrl, enc )
+		resp = u.read()
+		u.close
+
+		try:
+			parsed = xmlrpclib.loads( resp )[0][0]
+		except xmlrpclib.Fault, fault:
+			parsed = resp
+			print "Error:", fault.faultString
+			print "Code:", fault.faultCode
+
+		return parsed
+
 	def setTired( self, identity=None ):
 		if identity == None:
 			return
@@ -206,7 +234,7 @@ class Pandora:
 		u = urlopen( reqUrl, enc )
 		resp = u.read()
 		u.close
-
+		
 		try:
 			parsed = xmlrpclib.loads( resp )[0][0]
 		except xmlrpclib.Fault, fault:
