@@ -475,9 +475,6 @@ class Panda(QtGui.QMainWindow): #main class
 			self.player.createStationId = self.createStations[self.ui.listStations.currentIndex()]['musicId']
 			self.createStations = []
 			return
-
-		if self.player.playing:
-			self.player.stopPlayBack()
 		
 		if self.player.playStation > 0:
 			stationId = self.player.playStation
@@ -489,6 +486,8 @@ class Panda(QtGui.QMainWindow): #main class
 		self.player.getMoreSongs()
 		self.player.playing = True
 		self.playNextSong()
+		#if self.player.playing:
+			#self.player.stopPlayBack()
 		if stationId != self.c.lastplayed:
 			f = open(os.path.expanduser("~")+'/.config/pyradio/lastplayed', 'w')
 			f.write(self.player.curStation)
@@ -562,8 +561,6 @@ class Panda(QtGui.QMainWindow): #main class
 		self.ui.btnNext.setEnabled( True )
 
 	def skipSong( self ): #Skip song
-		self.ui.btnNext.setEnabled( False )
-		self.player.skip = True
 		self.skip = 0
 		self.player.stopPlayBack()
 
@@ -571,10 +568,6 @@ class Panda(QtGui.QMainWindow): #main class
 		self.player.playing = False
 
 	def closeEvent(self, event=None): #Exit application gracefully.. somewhat.
-		self.player.skip = False
-		if self.player.playing:
-			self.player.playing = False
-			self.player.stopPlayBack()
 		self.player.run = 0
 		self.player.close()
 		del self.ui
