@@ -14,7 +14,6 @@ class RadioPlayer(QtCore.QThread): #Main radio class
 	def __init__( self, Parent=None ):
 		self.timer = None
 		self.playing = 0
-		self.skip = False
 		self.run = 1
 		self.user = ""
 		self.password = ""
@@ -42,7 +41,7 @@ class RadioPlayer(QtCore.QThread): #Main radio class
 		else:
 			from libpiano.OSSOBackend import OSSOBackend
 			self.player = OSSOBackend()
-		QtCore.QObject.connect(self.player, QtCore.SIGNAL("eof"), self.onPlayBackEnded)
+		QtCore.QObject.connect(self.player, QtCore.SIGNAL("eof"), self.sigEOF)
 		QtCore.QObject.connect(self.player, QtCore.SIGNAL("state_change(int)"), self.stateChange)
 		QtCore.QObject.connect(self.player, QtCore.SIGNAL("pos_changed(int,int)"), self.updateTime)
 		self.stop = True
@@ -119,6 +118,8 @@ class RadioPlayer(QtCore.QThread): #Main radio class
 			self.emit(QtCore.SIGNAL("state(QString)"),"pause")
 		elif state == 1:
 			self.emit(QtCore.SIGNAL("state(QString)"),"play")
+		elif state == 0:
+			self.onPlayBackEnded()
 
 	def createStation( self ): #Create a station at Pandora
 		ret = self.pandora.createStation( self.createStationId )
@@ -153,20 +154,18 @@ class RadioPlayer(QtCore.QThread): #Main radio class
 				self.player.close()
 			else:
 				self.player.stop()
-				time.sleep ( 1 )
-
-			if self.skip and self.playing:
-				self.onPlayBackEnded()
+				self.onPlayBackEnded()		
 	
 	def startPlayBack ( self ): #Resume after Pause
 		self.player.play()
 
 	def onPlayBackEnded( self ): #EOF Reached, start next song.
-		if self.state == 0: #Sometimes when skipping we get an EOF signal, sometimes we don't.  I use this so we don't skip twice.
-			print "EOF called."
-			self.emit(QtCore.SIGNAL("PlayNext"))
-		else:
-			print "Skipped."
+		print "EOF called."
+		self.emit(QtCore.SIGNAL("PlayNext"))
+		
+	def sigEOF( self ):
+		if self.os != "RX-51":
+			self.onPlayBackEnded()
 
 	def LoveHate( self ): #Do Love/Hate based on variable settings
 		self.respLH = self.pandora.addFeedback( self.curSong[1]["stationId"], self.curSong, self.loveHateRating )
@@ -205,6 +204,7 @@ class RadioPlayer(QtCore.QThread): #Main radio class
 		for s in fragment:
 			#print s
 			#print "\n"
+			print s["songTitle"], "by", s["artistSummary"]
 			item = None
 			item = { "title" : s["songTitle"], \
 			"artist"	:	s["artistSummary"], \
